package com.example.profileviewersql;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.content.ContentValues;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.os.Bundle;
import android.text.Editable;
import android.text.TextWatcher;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemClickListener;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.EditText;
import android.widget.ListView;
import android.widget.TextView;

public class Main extends Activity implements OnClickListener {
	
    private static final int NAME_DIALOG_ID = 0;
    
    private ProfileDB profileDB = new ProfileDB(this);
	
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);
        
        ListView filters = (ListView) findViewById(R.id.user_list);
        filters.setAdapter(getCurrentUsers());
        filters.setChoiceMode(ListView.CHOICE_MODE_SINGLE);

        filters.setOnItemClickListener(new OnItemClickListener() {

			@Override
			public void onItemClick(AdapterView<?> list, View list_item, int position, long id) {
				if (position != -1) {
					TextView item = (TextView) list_item;
     				Log.i("Profile Viewer", "Item selected: " + item.getText());
     				
     		        Button edit_button = (Button)findViewById(R.id.edit_button); 
     		        Button remove_button = (Button)findViewById(R.id.remove_button);
     		        
     		        edit_button.setEnabled(true);
     		        remove_button.setEnabled(true);
				} else {
     				Log.i("Profile Viewer", "No Item Selected!");
     		        Button edit_button = (Button)findViewById(R.id.edit_button); 
	    			Button remove_button = (Button)findViewById(R.id.remove_button); 

     		        edit_button.setEnabled(false);
	    			remove_button.setEnabled(false);					
				}
			}
        	
        });
                
        Button add_button    = (Button)findViewById(R.id.add_button);
        Button edit_button   = (Button)findViewById(R.id.edit_button);
        Button remove_button = (Button)findViewById(R.id.remove_button);
        
        add_button.setOnClickListener(this);
        edit_button.setOnClickListener(this);
        remove_button.setOnClickListener(this);

        edit_button.setEnabled(false);
        remove_button.setEnabled(false);
        
    }
    
    @Override
    public void onResume() {
    	super.onResume();
        Log.i("ProfileData", "onResume()");        
    }
    
    @Override
    public void onPause() {
    	super.onPause();
        Log.i("ProfileData", "onPause()");
    }
    
    public void onClick(View v) {
    	switch (v.getId()) {
    	    case R.id.add_button:
    	    	showDialog(NAME_DIALOG_ID);
        		break;
    	    case R.id.edit_button:
    	    {
    	        ListView filters = (ListView) findViewById(R.id.user_list);
    	        int selected = filters.getCheckedItemPosition();
    	        TextView item = (TextView) filters.getChildAt(selected);
    	        Intent intent = new Intent(this, EditProfile.class);
    	        intent.putExtra("name", item.getText().toString());
    	        startActivity(intent);
    	    }
    	    	break;
    	    case R.id.remove_button:
    	    {
    	        ListView filters = (ListView) findViewById(R.id.user_list);
    	        int selected = filters.getCheckedItemPosition();
    	        TextView item = (TextView) filters.getChildAt(selected);
    	        remove_name(item.getText().toString());
    	    }
    	    	break;
    	}
    }
    
    @Override
    protected Dialog onCreateDialog(int id) {
    	switch (id) {
    	    case NAME_DIALOG_ID:
    	    	LayoutInflater inflater = (LayoutInflater) getSystemService(Context.LAYOUT_INFLATER_SERVICE);
    	    	final View layout = inflater.inflate(R.layout.name_dialog, (ViewGroup) findViewById(R.id.root));
    	    	final EditText name_field = (EditText) layout.findViewById(R.id.name_field);
    	    	final TextView error = (TextView) layout.findViewById(R.id.error);
    	    	name_field.addTextChangedListener(new TextWatcher() {

					@Override
					public void afterTextChanged(Editable s) {
						String name = name_field.getText().toString();
				        SQLiteDatabase db = profileDB.getReadableDatabase();
				        Cursor cursor = db.query("profiles", new String[] { "profile" }, "profile like ?", new String[] { name}, null, null, "profile");
						if (cursor.getCount() > 0) {
							error.setText("User name already exists!!");
						} else {
							error.setText("");
						}
				        cursor.close();
					}

					@Override
					public void beforeTextChanged(CharSequence s, int start,
							int count, int after) {
					}

					@Override
					public void onTextChanged(CharSequence s, int start,
							int before, int count) {
					}
    	    		
    	    	});
                AlertDialog.Builder builder = new AlertDialog.Builder(this);
                builder.setTitle("Add User").setView(layout);
                builder.setNegativeButton("Cancel",
                    new DialogInterface.OnClickListener() {
     					@Override
                        public void onClick(DialogInterface dialog, int whichButton) {
                        	Main.this.dismissDialog(NAME_DIALOG_ID);
                        }
                    });
                builder.setPositiveButton("Ok",
                    new DialogInterface.OnClickListener() {
						
						@Override
						public void onClick(DialogInterface dialog, int whichButton) {
                        	Main.this.dismissDialog(NAME_DIALOG_ID);
                        	EditText name_field = (EditText) layout.findViewById(R.id.name_field);
                        	Main.this.add_name(name_field.getText().toString());
						}                	
                    });
    	        return builder.create();
    	    default:
    	    	return null;
    	}
    }
    
    @Override
    protected void onPrepareDialog(int id, Dialog dialog) {
        super.onPrepareDialog(id, dialog);
    	switch (id) {
    	    case NAME_DIALOG_ID:
    	    	AlertDialog a = (AlertDialog) dialog;
    	    	EditText name_field = (EditText) a.findViewById(R.id.name_field);
    	    	name_field.setText("");
    	    	break;
    	    default:
    	    	break;
    	}
    }
    
    public void remove_name(String name) {
    	Log.i("Profile Viewer", "Please remove name: " + name);
    	
    	SQLiteDatabase db = profileDB.getWritableDatabase();
    	db.delete("profiles", "profile = ?", new String[] { name });
    	    	
       	ListView filters = (ListView) findViewById(R.id.user_list);        
        filters.setAdapter(getCurrentUsers());
    	
        Button edit_button = (Button)findViewById(R.id.edit_button); 
        Button remove_button = (Button)findViewById(R.id.remove_button);
        
        edit_button.setEnabled(false);
        remove_button.setEnabled(false);
        
    }
    
    public void add_name(String name) {
    	Log.i("Profile Viewer", "Please add name: " + name);
    	
    	SQLiteDatabase db = profileDB.getWritableDatabase();
    	ContentValues values = new ContentValues();
    	values.put("profile", name);
    	values.put("first", "Mr.");
    	values.put("last", "Nobody");
    	values.put("email", "nobody@example.com");
    	db.insertOrThrow("profiles", null, values);
    	    	
    	ListView filters = (ListView) findViewById(R.id.user_list);
        filters.setAdapter(getCurrentUsers());

        Button edit_button = (Button)findViewById(R.id.edit_button); 
        Button remove_button = (Button)findViewById(R.id.remove_button);
        
        edit_button.setEnabled(false);
        remove_button.setEnabled(false);
    }
    
    public ArrayAdapter<String> getCurrentUsers() {
                
        ArrayAdapter<String> adapter = new ArrayAdapter<String>(this, android.R.layout.simple_list_item_single_choice);

        SQLiteDatabase db = profileDB.getReadableDatabase();
        Cursor cursor = db.query("profiles", new String[] { "profile" }, null, null, null, null, "profile");
        while (cursor.moveToNext()) {
        	adapter.add(cursor.getString(0));
        }
        cursor.close();
                
    	return adapter;
    	
    }
    
    @Override
    public void onStop() {
    	super.onPause();
    	profileDB.close();
    }

}